@@ -311,9 +311,9 @@ class ModelResourceMeta(PresstResourceMeta):
                     if isinstance(column.type, postgres.ARRAY):
                         field_type = list
                     elif isinstance(column.type, postgres.HSTORE):
-                        field_type = fields.KeyValue()
+                        field_type = KeyValue
                     elif hasattr(postgres, 'JSON') and isinstance(column.type, postgres.JSON):
-                        field_type = JSON()
+                        field_type = JSON
                     else:
                         field_type = column.type.python_type
 
@@ -321,7 +321,10 @@ class ModelResourceMeta(PresstResourceMeta):
 
                     # Add to list of fields.
                     if not name in fields:
-                        field_class = class_._get_field_from_python_type(field_type)
+                        if isinstance(field_type, Raw):
+                            field_class = field_type
+                        else:
+                            field_class = class_._get_field_from_python_type(field_type)
 
                         # TODO implement support for ColumnDefault
                         # fields[name] = field_class(default=column.default)
